'use strict';

const Transform = require('stream').Transform;

class DelimiterStream extends Transform {
  constructor(delimiter, options) {
    super(options);
    this._buffer = [];
    this._delimiter = delimiter;
  }

  _transform(data, encoding, done) {
    data = data.toString();
    data = data.split(this._delimiter);
    if (data.length === 1) {
      // no special characters
      this._buffer.push(data[0]);
    } else {
      data.forEach((item, index) => {
        if (index === 0) {
          // first
          this._buffer.push(item);
          this.push(this._resolveBuffer());
        } else if (index === data.length - 1) {
          // last
          this._buffer.push(item);
        } else {
          this.push(item);
        }
      });
    }
    done();
  }

  _resolveBuffer() {
    var str = this._buffer.join('');
    this._buffer = [];
    return str;
  }

  _flush(done) {
    this.push(this._resolveBuffer());
    done();
  }
}

module.exports = DelimiterStream;
